StorageEntry

Struct StorageEntry 

pub struct StorageEntry {
    pub count: u64,
    pub window_start: u64,
    pub tat: Option<u64>,
    pub tokens: Option<f64>,
    pub last_update: u64,
    pub prev_count: Option<u64>,
    pub timestamps: Option<Vec<u64>>,
    pub metadata: Option<Vec<u8>>,
}
Entry stored in the storage backend.

This struct contains all state needed by rate limiting algorithms, designed to be flexible enough for any algorithm type.

Fields

count: u64

Request count (for window-based algorithms).

window_start: u64

Window start timestamp (Unix milliseconds).

tat: Option<u64>

Theoretical Arrival Time for GCRA (Unix milliseconds).

tokens: Option<f64>

Available tokens (for token bucket algorithm).

last_update: u64

Last update timestamp (Unix milliseconds).

prev_count: Option<u64>

Previous window count (for sliding window).

timestamps: Option<Vec<u64>>

Request timestamps (for sliding log algorithm).

metadata: Option<Vec<u8>>

Optional metadata (algorithm-specific).

Implementations

Source

impl StorageEntry

pub fn new(count: u64, window_start: u64) -> Self

Create a new storage entry for window-based algorithms.

pub fn with_tat(tat: u64) -> Self

Create a storage entry for GCRA algorithm.

pub fn with_tokens(tokens: f64, last_update: u64) -> Self

Create a storage entry for token bucket.

pub fn with_timestamps(timestamps: Vec<u64>) -> Self

Create a storage entry for sliding log.

pub fn set_tat(self, tat: u64) -> Self

Set the TAT value.

pub fn set_tokens(self, tokens: f64) -> Self

Set the token count.

pub fn set_last_update(self, last_update: u64) -> Self

Set the last update timestamp.

pub fn set_prev_count(self, count: u64) -> Self

Set previous window count.

pub fn set_metadata(self, metadata: Vec<u8>) -> Self

Set metadata.

pub fn tokens_or_default(&self) -> f64

Get tokens, defaulting to 0.0 if not set.

pub fn tat_or_default(&self) -> u64

Get TAT, defaulting to 0 if not set.